==> serenity-rest-assured-1.2.1-rc.4-sources.jar: net/serenitybdd/rest/decorators/request/RequestSpecificationSecurityConfigurations.java <==
package net.serenitybdd.rest.decorators.request;

import com.jayway.restassured.authentication.AuthenticationScheme;
import com.jayway.restassured.config.RestAssuredConfig;
import com.jayway.restassured.internal.AuthenticationSpecificationImpl;
import com.jayway.restassured.internal.RequestSpecificationImpl;
import com.jayway.restassured.specification.AuthenticationSpecification;
import com.jayway.restassured.specification.FilterableRequestSpecification;
import com.jayway.restassured.specification.RequestSpecification;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.security.KeyStore;

/**
 * User: YamStranger
 * Date: 3/16/16
 * Time: 2:08 PM
 */
abstract class RequestSpecificationSecurityConfigurations extends RequestSpecificationProxyConfigurations
        implements FilterableRequestSpecification {
    private static final Logger log = LoggerFactory.getLogger(RequestSpecificationSecurityConfigurations.class);

    public RequestSpecificationSecurityConfigurations(RequestSpecificationImpl core) {
        super(core);
    }

    @Override
    public RequestSpecification keystore(String pathToJks, String password) {
        core.keystore(pathToJks, password);
        return this;
    }

    @Override
    public RequestSpecification keystore(File pathToJks, String password) {
        core.keystore(pathToJks, password);
        return this;
    }

    @Override
    public RequestSpecification trustStore(KeyStore trustStore) {
        core.trustStore(trustStore);
        return this;
    }

    @Override
    public RequestSpecification relaxedHTTPSValidation() {
        return relaxedHTTPSValidation(RequestSpecificationImpl.SSL);
    }

    @Override
    public RequestSpecification relaxedHTTPSValidation(String protocol) {
        core.relaxedHTTPSValidation(protocol);
        return this;
    }

    @Override
    public AuthenticationSpecification authentication() {
        return new AuthenticationSpecificationImpl(this);
    }

    @Override
    public AuthenticationSpecification auth() {
        return authentication();
    }

    @Override
    public AuthenticationScheme getAuthenticationScheme() {
        return core.getAuthenticationScheme();
    }

    /**
     * Method created ONLY for using in groovy (rest assured internals)
     */
    protected void setAuthenticationScheme(final AuthenticationScheme scheme) {
        try {
            this.helper.setValueTo("authenticationScheme", scheme);
        } catch (Exception e) {
            throw new IllegalStateException
                    ("Can not set authenticationScheme from request, SerenityRest can work incorrectly");
        }
    }

    /**
     * Method created ONLY for using in groovy (rest assured internals)
     */
    protected RestAssuredConfig setauthenticationScheme() {
        return getRestAssuredConfig();
    }
}

==> serenity-rest-assured-1.5.4-rc.2-sources.jar: net/serenitybdd/rest/decorators/request/RequestSpecificationSecurityConfigurations.java <==
package net.serenitybdd.rest.decorators.request;

import io.restassured.authentication.AuthenticationScheme;
import io.restassured.config.RestAssuredConfig;
import io.restassured.internal.AuthenticationSpecificationImpl;
import io.restassured.internal.RequestSpecificationImpl;
import io.restassured.specification.AuthenticationSpecification;
import io.restassured.specification.FilterableRequestSpecification;
import io.restassured.specification.RequestSpecification;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.security.KeyStore;

/**
 * User: YamStranger
 * Date: 3/16/16
 * Time: 2:08 PM
 */
abstract class RequestSpecificationSecurityConfigurations extends RequestSpecificationProxyConfigurations
        implements FilterableRequestSpecification {
    private static final Logger log = LoggerFactory.getLogger(RequestSpecificationSecurityConfigurations.class);


    public RequestSpecificationSecurityConfigurations(RequestSpecificationImpl core) {
        super(core);
    }

    @Override
    public RequestSpecification keyStore(String pathToJks, String password) {
        core.keyStore(pathToJks, password);
        return this;
    }

    @Override
    public RequestSpecification keyStore(File pathToJks, String password) {
        core.keyStore(pathToJks, password);
        return this;
    }

    @Override
    public RequestSpecification trustStore(KeyStore trustStore) {
        core.trustStore(trustStore);
        return this;
    }

    @Override
    public RequestSpecification relaxedHTTPSValidation() {
        String protocol = "SSL";
        try {
            protocol = (String)helper.getValueFrom("SSL");
        } catch(IllegalAccessException | NoSuchFieldException ex) {
            log.error("Error when getting value of SSL field from RequestSpecification");
            protocol = "SSL";
        }
        return relaxedHTTPSValidation(protocol);
    }

    @Override
    public RequestSpecification relaxedHTTPSValidation(String protocol) {
        core.relaxedHTTPSValidation(protocol);
        return this;
    }

    @Override
    public AuthenticationSpecification authentication() {
        return new AuthenticationSpecificationImpl(this);
    }

    @Override
    public AuthenticationSpecification auth() {
        return authentication();
    }

    /**
     * Method created ONLY for using in groovy (rest assured internals)
     */
    protected void setAuthenticationScheme(final AuthenticationScheme scheme) {
        try {
            this.helper.setValueTo("authenticationScheme", scheme);
        } catch (Exception e) {
            throw new IllegalStateException
                    ("Can not set authenticationScheme from request, SerenityRest can work incorrectly");
        }
    }

    /**
     * Method created ONLY for using in groovy (rest assured internals)
     */
    protected RestAssuredConfig setauthenticationScheme() {
        return getRestAssuredConfig();
    }
}
